@@ -67,22 +67,22 @@ class Exceptions:
 
 class CognitoSyncClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/cognito-sync.html#CognitoSync.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html)
     """
 
     meta: ClientMeta
     exceptions: Exceptions
 
-    def bulk_publish(self, IdentityPoolId: str) -> BulkPublishResponseTypeDef:
+    def bulk_publish(self, *, IdentityPoolId: str) -> BulkPublishResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/cognito-sync.html#CognitoSync.Client.bulk_publish)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.bulk_publish)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#bulk_publish)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/cognito-sync.html#CognitoSync.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#can_paginate)
         """
 
@@ -90,7 +90,7 @@ class CognitoSyncClient:
         self, *, IdentityPoolId: str, IdentityId: str, DatasetName: str
     ) -> DeleteDatasetResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/cognito-sync.html#CognitoSync.Client.delete_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.delete_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#delete_dataset)
         """
 
@@ -98,23 +98,23 @@ class CognitoSyncClient:
         self, *, IdentityPoolId: str, IdentityId: str, DatasetName: str
     ) -> DescribeDatasetResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/cognito-sync.html#CognitoSync.Client.describe_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.describe_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#describe_dataset)
         """
 
     def describe_identity_pool_usage(
-        self, IdentityPoolId: str
+        self, *, IdentityPoolId: str
     ) -> DescribeIdentityPoolUsageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/cognito-sync.html#CognitoSync.Client.describe_identity_pool_usage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.describe_identity_pool_usage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#describe_identity_pool_usage)
         """
 
     def describe_identity_usage(
-        self, IdentityPoolId: str, IdentityId: str
+        self, *, IdentityPoolId: str, IdentityId: str
     ) -> DescribeIdentityUsageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/cognito-sync.html#CognitoSync.Client.describe_identity_usage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.describe_identity_usage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#describe_identity_usage)
         """
 
@@ -126,27 +126,29 @@ class CognitoSyncClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/cognito-sync.html#CognitoSync.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#generate_presigned_url)
         """
 
-    def get_bulk_publish_details(self, IdentityPoolId: str) -> GetBulkPublishDetailsResponseTypeDef:
+    def get_bulk_publish_details(
+        self, *, IdentityPoolId: str
+    ) -> GetBulkPublishDetailsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/cognito-sync.html#CognitoSync.Client.get_bulk_publish_details)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.get_bulk_publish_details)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#get_bulk_publish_details)
         """
 
-    def get_cognito_events(self, IdentityPoolId: str) -> GetCognitoEventsResponseTypeDef:
+    def get_cognito_events(self, *, IdentityPoolId: str) -> GetCognitoEventsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/cognito-sync.html#CognitoSync.Client.get_cognito_events)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.get_cognito_events)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#get_cognito_events)
         """
 
     def get_identity_pool_configuration(
-        self, IdentityPoolId: str
+        self, *, IdentityPoolId: str
     ) -> GetIdentityPoolConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/cognito-sync.html#CognitoSync.Client.get_identity_pool_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.get_identity_pool_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#get_identity_pool_configuration)
         """
 
@@ -154,15 +156,15 @@ class CognitoSyncClient:
         self, *, IdentityPoolId: str, IdentityId: str, NextToken: str = None, MaxResults: int = None
     ) -> ListDatasetsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/cognito-sync.html#CognitoSync.Client.list_datasets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.list_datasets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#list_datasets)
         """
 
     def list_identity_pool_usage(
-        self, NextToken: str = None, MaxResults: int = None
+        self, *, NextToken: str = None, MaxResults: int = None
     ) -> ListIdentityPoolUsageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/cognito-sync.html#CognitoSync.Client.list_identity_pool_usage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.list_identity_pool_usage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#list_identity_pool_usage)
         """
 
@@ -178,7 +180,7 @@ class CognitoSyncClient:
         SyncSessionToken: str = None
     ) -> ListRecordsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/cognito-sync.html#CognitoSync.Client.list_records)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.list_records)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#list_records)
         """
 
@@ -186,13 +188,13 @@ class CognitoSyncClient:
         self, *, IdentityPoolId: str, IdentityId: str, Platform: PlatformType, Token: str
     ) -> RegisterDeviceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/cognito-sync.html#CognitoSync.Client.register_device)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.register_device)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#register_device)
         """
 
-    def set_cognito_events(self, IdentityPoolId: str, Events: Dict[str, str]) -> None:
+    def set_cognito_events(self, *, IdentityPoolId: str, Events: Dict[str, str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/cognito-sync.html#CognitoSync.Client.set_cognito_events)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.set_cognito_events)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#set_cognito_events)
         """
 
@@ -204,7 +206,7 @@ class CognitoSyncClient:
         CognitoStreams: "CognitoStreamsTypeDef" = None
     ) -> SetIdentityPoolConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/cognito-sync.html#CognitoSync.Client.set_identity_pool_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.set_identity_pool_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#set_identity_pool_configuration)
         """
 
@@ -212,7 +214,7 @@ class CognitoSyncClient:
         self, *, IdentityPoolId: str, IdentityId: str, DatasetName: str, DeviceId: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/cognito-sync.html#CognitoSync.Client.subscribe_to_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.subscribe_to_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#subscribe_to_dataset)
         """
 
@@ -220,7 +222,7 @@ class CognitoSyncClient:
         self, *, IdentityPoolId: str, IdentityId: str, DatasetName: str, DeviceId: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/cognito-sync.html#CognitoSync.Client.unsubscribe_from_dataset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.unsubscribe_from_dataset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#unsubscribe_from_dataset)
         """
 
@@ -236,6 +238,6 @@ class CognitoSyncClient:
         ClientContext: str = None
     ) -> UpdateRecordsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/cognito-sync.html#CognitoSync.Client.update_records)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.97/reference/services/cognito-sync.html#CognitoSync.Client.update_records)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/client.html#update_records)
         """
