@@ -1,7 +1,7 @@
 """
 Type annotations for cognito-sync service type definitions.
 
-[Open documentation](./type_defs.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_sync/type_defs.html)
 
 Usage::
 
@@ -15,7 +15,7 @@ import sys
 from datetime import datetime
 from typing import Dict, List
 
-from .literals import BulkPublishStatus, Operation, StreamingStatus
+from .literals import BulkPublishStatusType, OperationType, StreamingStatusType
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -60,7 +60,7 @@ CognitoStreamsTypeDef = TypedDict(
     {
         "StreamName": str,
         "RoleArn": str,
-        "StreamingStatus": StreamingStatus,
+        "StreamingStatus": StreamingStatusType,
     },
     total=False,
 )
@@ -117,7 +117,7 @@ GetBulkPublishDetailsResponseTypeDef = TypedDict(
         "IdentityPoolId": str,
         "BulkPublishStartTime": datetime,
         "BulkPublishCompleteTime": datetime,
-        "BulkPublishStatus": BulkPublishStatus,
+        "BulkPublishStatus": BulkPublishStatusType,
         "FailureMessage": str,
     },
     total=False,
@@ -213,7 +213,7 @@ PushSyncTypeDef = TypedDict(
 _RequiredRecordPatchTypeDef = TypedDict(
     "_RequiredRecordPatchTypeDef",
     {
-        "Op": Operation,
+        "Op": OperationType,
         "Key": str,
         "SyncCount": int,
     },
